﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.ServiceModel.Syndication;
using System.Text.RegularExpressions;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Xml;
using Channel9Reader.RssGetReference;
using Telerik.Windows.Controls;


namespace Channel9Reader
{
	public partial class Page : UserControl
	{
		private MSDNChannels _msdnChannels = new MSDNChannels();
		private Size DefaultMediaPlayerSize = new Size(1024, 768);
		
		public Page()
		{
			InitializeComponent();
			
			Loaded += new RoutedEventHandler(Page_Loaded);
			RadMediaPlayer1.FullScreenChanged += new EventHandler(RadMediaPlayer1_FullScreenChanged);
		}

		private void Page_Loaded(object sender, RoutedEventArgs e)
		{
			RssGetClient channel9Client = new RssGetClient();
			channel9Client.GetFeedCompleted += new EventHandler<GetFeedCompletedEventArgs>(Client_GetFeedCompleted);
			// fire the animation that will be displayed while loading the data
			SpinAnimation.Begin();
			// begin downloading the data
			channel9Client.GetFeedAsync("http://channel9.msdn.com/Feeds/RSS/");
		}

		private void Client_GetFeedCompleted(object sender, GetFeedCompletedEventArgs e)
		{
			if (e.Error != null)
			{
				ErrorMessageTextBlock.Text = "Connection failed. Please refresh the page.";
				return;
			}
			
			StringReader result = new StringReader(e.Result);
			XmlReader xmlReader = XmlReader.Create(result);
			SyndicationFeed feed = SyndicationFeed.Load(xmlReader);
			var items = feed.Items.ToList();
			// go through the items that have been received from the feed
			foreach (var item in items)
			{
				// most of the code bellow is based on the result that has been returned. 
				// since the feed returns items that do not have video, we should check whether the ID contains the wmv, that indicates that the item has video file in it.
				if (item.Id.Contains("wmv"))
				{
					Channel9Item channelItem = new Channel9Item();
					channelItem.VideoSource = new Uri(item.Id, UriKind.RelativeOrAbsolute);
					channelItem.Title = item.Title.Text;
					// the RegEx bellow removes all the information that is within tags(links, paragraphs etc.)
					channelItem.Description = Regex.Replace(item.Summary.Text, "<(.|\n)+?>", "");
					// we assume that the item does not have image to display
					channelItem.ImageSource = new BitmapImage(new Uri("no_picture.png", UriKind.RelativeOrAbsolute));
					// if the summary text has _ch9 string this means that it contains an image, so we have to do some text processing to get it
					if (item.Summary.Text.Contains("_ch9"))
					{
						int beginIndex = item.Summary.Text.IndexOf("http");
						int endIndex = item.Summary.Text.IndexOf("_ch9") - 2;

						string imageUrl = item.Summary.Text.Substring(beginIndex, endIndex);
						imageUrl = imageUrl.Replace("small", "large");
						channelItem.ImageSource = new BitmapImage(new Uri(imageUrl, UriKind.RelativeOrAbsolute));
					}
					//create a media item and load its template from the Resources of the page
					RadMediaItem mediaItem = new RadMediaItem();
					mediaItem.Template = Resources["Channel9MediaItemTemplate"] as ControlTemplate;
					mediaItem.DataContext = channelItem;
					mediaItem.Source = channelItem.VideoSource;

					_msdnChannels.Channel9List.Add(mediaItem);
				}
			}

			RadMediaPlayer1.DataContext = _msdnChannels;
			Loading.Visibility = Visibility.Collapsed;
		}
		
		private void RadMediaPlayer1_FullScreenChanged(object sender, EventArgs e)
		{
			Application.Current.Host.Content.IsFullScreen = RadMediaPlayer1.IsFullscreen;

			if (Application.Current.Host.Content.IsFullScreen)
			{
				RadMediaPlayer1.Width = Application.Current.Host.Content.ActualWidth;
				RadMediaPlayer1.Height = Application.Current.Host.Content.ActualHeight;
			}
			else
			{
				RadMediaPlayer1.Width = DefaultMediaPlayerSize.Width;
				RadMediaPlayer1.Height = DefaultMediaPlayerSize.Height;
				RadMediaPlayer1.IsFullscreen = false;
			}

		}

	}
}
